@@ -64,6 +64,9 @@ BoolOpMap = {
     Or: plt.Or,
 }
 
+UnaryOpMap = {
+    Not: plt.Not,
+}
 
 ConstantMap = {
     str: plt.Text,
@@ -157,6 +160,13 @@ class UPLCCompiler(CompilingNodeTransformer):
             ops,
         )
 
+    def visit_UnaryOp(self, node: TypedUnaryOp) -> plt.AST:
+        op = UnaryOpMap.get(type(node.op))
+        return plt.Lambda(
+            [STATEMONAD],
+            op(plt.Apply(self.visit(node.operand), plt.Var(STATEMONAD))),
+        )
+
     def visit_Compare(self, node: TypedCompare) -> plt.AST:
         assert len(node.ops) == 1, "Only single comparisons are supported"
         assert len(node.comparators) == 1, "Only single comparisons are supported"
